==> aws-sdk-cpp-1.11.124-1-x86_64.pkg.tar.zst: usr/include/aws/pinpoint/PinpointEndpointProvider.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/pinpoint/Pinpoint_EXPORTS.h>
#include <aws/core/client/GenericClientConfiguration.h>
#include <aws/core/endpoint/DefaultEndpointProvider.h>
#include <aws/core/endpoint/EndpointParameter.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>

#include <aws/pinpoint/PinpointEndpointRules.h>


namespace Aws
{
namespace Pinpoint
{
namespace Endpoint
{
using EndpointParameters = Aws::Endpoint::EndpointParameters;
using Aws::Endpoint::EndpointProviderBase;
using Aws::Endpoint::DefaultEndpointProvider;

using PinpointClientContextParameters = Aws::Endpoint::ClientContextParameters;

using PinpointClientConfiguration = Aws::Client::GenericClientConfiguration<false>;
using PinpointBuiltInParameters = Aws::Endpoint::BuiltInParameters;

/**
 * The type for the Pinpoint Client Endpoint Provider.
 * Inherit from this Base class / "Interface" should you want to provide a custom endpoint provider.
 * The SDK must use service-specific type for each service per specification.
 */
using PinpointEndpointProviderBase =
    EndpointProviderBase<PinpointClientConfiguration, PinpointBuiltInParameters, PinpointClientContextParameters>;

using PinpointDefaultEpProviderBase =
    DefaultEndpointProvider<PinpointClientConfiguration, PinpointBuiltInParameters, PinpointClientContextParameters>;

/**
 * Default endpoint provider used for this service
 */
class AWS_PINPOINT_API PinpointEndpointProvider : public PinpointDefaultEpProviderBase
{
public:
    using PinpointResolveEndpointOutcome = Aws::Endpoint::ResolveEndpointOutcome;

    PinpointEndpointProvider()
      : PinpointDefaultEpProviderBase(Aws::Pinpoint::PinpointEndpointRules::GetRulesBlob(), Aws::Pinpoint::PinpointEndpointRules::RulesBlobSize)
    {}

    ~PinpointEndpointProvider()
    {
    }
};
} // namespace Endpoint
} // namespace Pinpoint
} // namespace Aws

==> aws-sdk-cpp-1.11.676-1-x86_64.pkg.tar.zst: usr/include/aws/pinpoint/PinpointEndpointProvider.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/pinpoint/Pinpoint_EXPORTS.h>
#include <aws/core/client/GenericClientConfiguration.h>
#include <aws/core/endpoint/DefaultEndpointProvider.h>
#include <aws/core/endpoint/EndpointParameter.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>

#include <aws/pinpoint/PinpointEndpointRules.h>


namespace Aws
{
namespace Pinpoint
{
namespace Endpoint
{
using EndpointParameters = Aws::Endpoint::EndpointParameters;
using Aws::Endpoint::EndpointProviderBase;
using Aws::Endpoint::DefaultEndpointProvider;

using PinpointClientContextParameters = Aws::Endpoint::ClientContextParameters;

using PinpointClientConfiguration = Aws::Client::GenericClientConfiguration;
using PinpointBuiltInParameters = Aws::Endpoint::BuiltInParameters;

/**
 * The type for the Pinpoint Client Endpoint Provider.
 * Inherit from this Base class / "Interface" should you want to provide a custom endpoint provider.
 * The SDK must use service-specific type for each service per specification.
 */
using PinpointEndpointProviderBase =
    EndpointProviderBase<PinpointClientConfiguration, PinpointBuiltInParameters, PinpointClientContextParameters>;

using PinpointDefaultEpProviderBase =
    DefaultEndpointProvider<PinpointClientConfiguration, PinpointBuiltInParameters, PinpointClientContextParameters>;

/**
 * Default endpoint provider used for this service
 */
class AWS_PINPOINT_API PinpointEndpointProvider : public PinpointDefaultEpProviderBase
{
public:
    using PinpointResolveEndpointOutcome = Aws::Endpoint::ResolveEndpointOutcome;

    PinpointEndpointProvider()
      : PinpointDefaultEpProviderBase(Aws::Pinpoint::PinpointEndpointRules::GetRulesBlob(), Aws::Pinpoint::PinpointEndpointRules::RulesBlobSize)
    {}

    ~PinpointEndpointProvider()
    {
    }
};
} // namespace Endpoint
} // namespace Pinpoint
} // namespace Aws
